@@ -88,13 +88,13 @@ class FreqDict(models.Model):
             #Orthography.objects.bulk_create(ss)
             #w.Orthographies.add(*ss)
             #wf = WordForm.objects.create(pk=int(key),Lemma = lem[0],Frequency = int(wfs[key]['Freq']))
-            ss = (Orthography.objects.get_or_create(Spelling=s)[0] for s in wfs[w.pk]['Spellings'])
+            ss = (Orthography.objects.get_or_create(Spelling=s)[0] for s in wfs[str(w.pk)]['Spellings'])
             w.Orthographies.add(*ss)
             ts = (Transcription.objects.get_or_create(Transcription=t
-                    ,CVSkel=re.sub('[^IE{VQU@i#$u312456789cq0~]','C',
+                    ,defaults={'CVSkel':re.sub('[^IE{VQU@i#$u312456789cq0~]','C',
                                 re.sub('[IE{VQU@i#$u312456789cq0~]','V',
-                                    re.sub(r'[-"\']','',t))))[0]
-                        for t in wfs[w.pk]['Transcriptions'])
+                                    re.sub(r'[-"\']','',t)))})[0]
+                        for t in wfs[str(w.pk)]['Transcriptions'])
             w.Transcriptions.add(*ts)
 
     def loadOrthLemmas(self):
