@@ -87,7 +87,7 @@ def string_selection(request):
             #    qs = filter(lambda q: len(q.Transcriptions.
             qs = qs.filter(Transcriptions__CVSkel = forms.cleaned_data['cvskel'])
             for q in qs:
-                if len(q.Transcriptions.all() != 1:
+                if len(q.Transcriptions.all()) != 1:
                     continue
                 t = q.Transcriptions.all()[0]
                 s = q.Orthographies.all()[0]
